#
# spec file for package libcosmos
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define version 0.3.1

Name:           libcosmos
Version:        %{version}
Release:        1.1
Summary:        A library providing a modern C++ API for the Linux operating system
License:        MIT
Group:          Development/Libraries/C and C++
URL:            https://github.com/gerstner-hub/libcosmos
Source0:        libcosmos-v0.3.1.tar.xz

BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  scons

%description
This is libcosmos, a library providing a modern C++ API for the Linux
operating system. It is intended for low level systems programming on Linux,
while relying on a strong C++ type model for robustness and expressiveness.

%package -n libcosmos-3
Summary:        A library providing a modern C++ API for the Linux operating system
Group:          System/Libraries
Provides:       %{name} = %{version}
Obsoletes:      %{name} < %{version}
# renamed from broken package name that didn't follow SONAME
Provides:       libcosmos-0_2_0 = %{version}
Obsoletes:      libcosmos-0_2_0 < %{version}

%description -n libcosmos-3
A library providing a modern C++ API for the Linux operating system.

The runtime library files for libcosmos.

%package devel
Summary:        A library providing a modern C++ API for the Linux operating system
Group:          Development/Libraries/C and C++
Requires:       libcosmos-3 = %{version}
Requires:       libstdc++-devel

%description devel
A library providing a modern C++ API for the Linux operating system.

Header and development files for libcosmos.

%prep
%setup -q -n %{name}-v%{version}

%build
scons libtype=shared

%install
scons install instroot=%{buildroot}/usr

# some of the tests rely on networking so skip them for now
#%%check
#scons run_tests

%ldconfig_scriptlets -n libcosmos-3

%files -n libcosmos-3
%license LICENSE
%doc README.md
%{_libdir}/libcosmos.so.*

%files devel
%{_libdir}/libcosmos.so
%{_libdir}/pkgconfig/*.pc
%{_includedir}/cosmos/

%changelog
* Tue Aug  6 2024 Matthias Gerstner <matthias.gerstner@suse.com>
- Setup obsoletes/provides to cover the renaming of the library SONAME.
* Tue Aug  6 2024 Matthias Gerstner <matthias.gerstner@suse.com>
- update to first source tarball release v0.3.1. Drop git SCM service.
* Wed Jul 24 2024 Matthias Gerstner <matthias.gerstner@suse.com>
- change library package name from libcosmos-0_2_0 to libcosmos-0, because it
  needs to follow the library's SONAME which is libcosmos.so.0.
* Wed Jul 24 2024 matthias.gerstner@suse.com
- Update to version 0.2.1+gitcb2663e:
  * buildsystem: fix bug in passing multiple parameters via CXXFLAGS & friends
  * test/thread.cxx: fix potential race condition in isCallerThread()
  * buildsystem: passthrough ASAN_OPTIONS
  * tests: on unit test error cat logfile to stderr
  * bump lib version which now contains memory mapping API
  * github action: disable ODR iolation checks in unit tests in sanitizer build
  * README.md: add info about recent developments
  * check.py: support more fine tuning regarding which configs are built
  * tests: mman: disable core dumping for expected SEGFAULT
  * check.py: use dedicated buildroot that is cleaned before each config
  * LinkLayerAddress: make some exotic protocols optional
  * support older toolchains and non-x86 architectures better
  * buildsystem.py: be prepared for TERM not existing
  * buildsystem.py: satisfy flake8 "missing whitespace after comma"
  * check.py: refer to current HEAD, not to master
  * .github: add github action workflow file
  * global: fix spelling errors in comments and documentation
  * mman.hxx: fix doxygen list item indentation
  * README: remove mention of memory mappings, which are available by now
  * addrinfo test: switch UDP resolve from http to tftp
  * feature: add support for memory mapping functionality
  * FileBase: add runcate() member function
  * FileDescriptor: provide default constructor to avoid initialization issues
  * thread: ignore destroy_res explicitly for NDEBUG builds
  * buildsystem: support NDEBUG build
  * buildsystem: support non standard compilers
* Wed Mar  6 2024 matthias.gerstner@suse.com
- Update to version 0.2.0+gita8e6f94:
  * GroupInfo: fix system include style
  * global: use angle bracket includes for libcosmos
  * string.hxx: add wide-string variant for to_lower(), to_upper()
  * string.hxx. support wide string strip() operation
  * byte_order: add default constructor for EndianNumber
- this fixes a broken -debugsource package generation
* Wed Feb 21 2024 matthias.gerstner@suse.com
- Update to version 0.2.0+gitff219ee:
  * ILogger: support a prefix() to be added to each log message
  * ILogger: use more robust way to detect std::cout and std::cerr
  * trivial: SocketAddress: remove superfluous slash in comment
* Fri Feb 16 2024 matthias.gerstner@suse.com
- Update to version 0.2.0+git7f2b8ee:
  * formatting: export another definition missing on 32-bit archs
  * scripts: use single quotes throughout
  * check.py: build all targets
  * buildsystem: support disabling doc build
  * check.py: select proper root directory for non-libcosmos projects
  * buildsystem: use single quotes throughout
  * buildsystem: use -fdiagnostics-color=auto instead of colorgcc wrapper
  * python files: incorporate Flake8 findings
  * check.py: also fun flake8 on Python files
  * buildsystem: support including local libraries with fallback to system pkg
  * PosixThread: fix race condition in setting m_pthread
  * buildsystem: support configuring default library type for project
* Tue Feb 13 2024 matthias.gerstner@suse.com
- Update to version 0.2.0+git33d893b:
  * buildsystem: support transparent use of local lib or system lib
* Mon Feb  5 2024 matthias.gerstner@suse.com
- Update to version c4e5e5e:
  * SecretFile: fix compilation path where SYS_memfd_secret is not defined
* Fri Feb  2 2024 matthias.gerstner@suse.com
- Update to version b459a4d:
  * check: also build 32-bit configurations
  * FileDescriptor: fix fcntl(F_DUPFD_CLOEXEC) API
  * tests: formatting: use proper format string (triggers warning on 32-bit)
  * formatting: properly instantiate on 32-bit machines
  * buildsystem: support LDFLAGS extension
  * buildsystem: ensure we get a 64-bit off_t on Linux even on 32-bit machines
  * clone: fix cast of pidfd pointer for 32-bit platforms
  * DirEntry: use off_t for DirPos
* Wed Jan 31 2024 Matthias Gerstner <matthias.gerstner@suse.com>
- initial packaging
